@@ -431,13 +431,18 @@ class Base(Controller):
             (['-n','--show_n'],{
                 "help" : "Number of recent files to show",
                 "action" : "store",
-                "default" : 25
+                "default" : 50
             }),
             (['-f','--filter'],{
                 "help" : "Filter the files by this int",
                 "action" : "store",
                 "default" : 0
             }),
+            (['-F','--file'],{
+                "help": "File containing metadata",
+                "action": "store",
+                "default": "/home/jakub/data/asco/devices.csv"
+            })
         ]
     )
     def s3(self):
@@ -448,15 +453,17 @@ class Base(Controller):
         # ls actions for all dongle ids
         if self.app.pargs.action == 'ls':
             filter = self.app.pargs.__dict__.get('filter') or self.app.pargs.__dict__.get('f') or 0
+            metadata_file = self.app.pargs.__dict__.get('file') or self.app.pargs.__dict__.get('F')
             
             from ..ext.aws_s3 import get_drives
             show_n = int(self.app.pargs.__dict__.get('show_n') or self.app.pargs.__dict__.get('n'))
 
             if self.app.pargs.target == '-1':
-                get_drives(self.app.pargs.target, show_n=show_n)
+                get_drives(self.app.pargs.target, show_n=show_n, metadata_file=metadata_file, filter=filter)
             else:
                 num_segments = self.app.pargs.__dict__.get('n') or self.app.pargs.__dict__.get('num_segments')
-                get_drives(self.app.pargs.target, show_n=show_n, num_segments = num_segments, filter=int(filter))
+                get_drives(self.app.pargs.target, show_n=show_n, metadata_file=metadata_file, 
+                            num_segments = num_segments, filter=int(filter))
 
         if self.app.pargs.action == 'pull':
             from ..ext.aws_s3 import pull_latest
