@@ -71,8 +71,15 @@ def get_drives_df(s3_resource, bucket_name, dongle_id: str, filter=0):
 
     return df
 
-def get_selected_drives(s3, s3_resource, bucket_name, dongle_id, show_n):
+def get_selected_drives(s3, s3_resource, bucket_name, dongle_id):
+    """
+    Get the selected drives for a dongle.
+    """
     df = get_drives_df(s3_resource, bucket_name, dongle_id)
+    
+    if dongle_id=='064b1a99381ec054':
+        # import ipdb; ipdb.set_trace()
+        pass
 
     if len(df) == 0:
         print(f"No files found for {dongle_id}")
@@ -98,7 +105,7 @@ def get_dongle_drives(s3, s3_resource, bucket_name, dongle_id: str, show_n: int,
     latest_files = []
 
     for did in tqdm(sorted(dongle_ids[:show_n])):
-        latest_drive, last_complete_drive = get_selected_drives(s3, s3_resource, bucket_name, did, show_n)
+        latest_drive, last_complete_drive = get_selected_drives(s3, s3_resource, bucket_name, did)
         # TODO: this does not feel like the last file
         if latest:       latest_files.append(last_complete_drive)
         else:  latest_files.append(latest_drive)
@@ -108,7 +115,7 @@ def get_dongle_drives(s3, s3_resource, bucket_name, dongle_id: str, show_n: int,
     return df
     
 
-def get_drives(target, bucket_name: str = 'creationlabs-raw-data', 
+def get_drives(target, bucket_name: str = 'creationlabs-raw-data', metadata_file: str = '/home/jakub/data/asco/devices.csv',
                         show_n: int = 25, num_segments: int = 1, filter=0):
     # TODO: profile
     # get all dongle ids
@@ -127,6 +134,7 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data',
     else:
         df = get_drives_df(s3_resource, bucket_name, dongle_id=target, filter=filter)
 
+    # import ipdb; ipdb.set_trace()
     df['upload_time'] = df.drive.str.split('--').str[:-1].str.join('--')
 
     # TODO: fix this
@@ -139,7 +147,8 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data',
 
 
     if target in ['0', '-1']:
-        df = df[['dongle_id','drive','time','seg_num']]
+        df = add_metadata(df, metadata_file)
+        df = df[['dongle_id','drive','time','seg_num','Registration Number']]
         print(df.head(show_n))
     else:
         df['link'] = df.apply(lambda x: urlifier(x.dongle_id, x.drive_time), axis=1)
@@ -161,4 +170,20 @@ def pull_latest(dongle_id):
     # s3.meta.client.download_file(bucket, last_drive, dongle_id)
     cmd = f'aws s3 sync s3://{bucket}/{dongle_id} .  --exclude="*" --include="{last_drive}*"'
     print(f"Running {cmd}")
-    os.system(cmd)
\ No newline at end of file
+    os.system(cmd)
+
+
+def add_metadata(df: pd.DataFrame, metadata_file_path: str):
+    """
+    Add metadata to the dataframe.
+    """
+
+    if not os.path.exists(metadata_file_path):
+        print(f"Metadata file {metadata_file_path} not found")
+        return df
+
+    meta_data = pd.read_csv(metadata_file_path)
+
+    # merge the two dataframes
+    df = df.merge(meta_data, left_on='dongle_id', right_on="Dongle ID")
+    return df
\ No newline at end of file
